==> nui_web-0.0.24.tar.gz: lib/nui_web_models.dart <==
import 'dart:convert';
import 'package:flutter/cupertino.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/data/nui_ent.dart';

enum NUIWebMethod{
  PUT,
  POST,
  PATCH,
  DELETE,
  GET
}

abstract class NUIWebInterceptor{
  Future<NUIWebInterceptorResponse> intercept(String url, NUIWebMethod method, dynamic, Map<String, String> headers, Map<String, dynamic> body);
}

class NUIWebInterceptorResponse extends NUIStandardHttpResponse{
  NUIWebInterceptorResponse({String message, bool success, Map<String, dynamic> data, this.interceptResponse, int code}){
    this.message = message;
    this.success = success;
    this.data = data;
    this.code = code;
  }

  bool interceptResponse;
}

class NUIStandardHttpResponse extends NUIEnt<NUIStandardHttpResponse>{
  NUIStandardHttpResponse.empty();
  NUIStandardHttpResponse();
  String message;
  bool success;
  bool status;
  int code;
  Map<String, dynamic> data;

  @override
  NUIEntMapper<NUIStandardHttpResponse> mapper() => NUIStandardHttpResponseEntity();

  T getDataAsObj<T extends NUIEnt>(NUIEntMapper<T> entity){
    try{
      return entity.toEntity(data);
    }
    catch(e){
      logNUI("NUIStandardHttpResponse", "Failed to parse body to object with error : $e");
      return null;
    }
  }
}
class NUIStandardHttpResponseEntity extends NUIEntMapper<NUIStandardHttpResponse>{
  @override
  String entityName() => "NUIStandardHttpResponse";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIStandardHttpResponse>(name: "message", type: NUIEntType.STRING, setter: (data, value) => data.message = value, getter: (data) => data.message),
      NUIEntField<NUIStandardHttpResponse>(name: "code", type: NUIEntType.INTEGER, setter: (data, value) => data.code = value, getter: (data) => data.code),
      NUIEntField<NUIStandardHttpResponse>(name: "success", type: NUIEntType.BOOLEAN, setter: (data, value) => data.success = value, getter: (data) => data.success),
      NUIEntField<NUIStandardHttpResponse>(name: "status", type: NUIEntType.BOOLEAN, setter: (data, value) => data.status = value, getter: (data) => data.status),
      NUIEntField<NUIStandardHttpResponse>(name: "data", type: NUIEntType.MAP, setter: (data, value) => data.data = value, getter: (data) => data.data),
    ];
  }

  @override
  NUIStandardHttpResponse newInstance() => NUIStandardHttpResponse.empty();
}

class NUIHttpResponse<T>{
  NUIHttpResponse({@required this.success, @required this.code, @required this.message, this.body, this.listBody, this.response, this.responseBody, this.headers});
  bool success;
  int code;
  String message;
  T body;
  List<T> listBody;
  String response;
  Map<String, String> headers;
  dynamic responseBody;

  NUIHttpStandardErrorResponse getErrorAsEnt(){
    if(responseBody != null){
      try{
        return NUIHttpStandardResponseEntity().toEntity(responseBody);
      }catch(e){
        print("NUIHttpResponse -> Error getting error response as object with error : $e");
      }
    }
    return null;
  }
}

class NUIHttpCacheResponse extends NUIEnt<NUIHttpCacheResponse>{
  NUIHttpCacheResponse({this.response, this.headers});
  NUIHttpCacheResponse.empty();
  String response;
  Map<String, String> headers;

  T getResponseAsEnt<T extends NUIEnt>(NUIEntMapper<T> entity){
    if(isNullOrEmpty(response)) return null;
    try{
      return entity.toEntity(jsonDecode(response));
    }catch(e){
      logNUI("NUIHttpCacheResponse", "Error parsing response to entity : ${entity.entityName()}");
    }
  }

  @override
  NUIEntMapper<NUIHttpCacheResponse> mapper() => NUIHttpCacheResponseEntity();
}

class NUIHttpCacheResponseEntity extends NUIEntMapper<NUIHttpCacheResponse>{
  @override
  String entityName() => "NUIHttpCacheResponse";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIHttpCacheResponse>(name: "response", type: NUIEntType.STRING, setter: (data, value) => data.response = value, getter: (data) => data.response),
      NUIEntField<NUIHttpCacheResponse>(name: "headers", type: NUIEntType.MAP, setter: (data, value) => data.headers = value, getter: (data) => data.headers),
    ];
  }

  @override
  NUIHttpCacheResponse newInstance() => NUIHttpCacheResponse.empty();
}

class NUIHttpStandardErrorResponse extends NUIEnt<NUIHttpStandardErrorResponse>{
  NUIHttpStandardErrorResponse.empty();
  String timestamp;
  int status;
  String error;
  String message;
  String path;

  @override
  NUIEntMapper<NUIHttpStandardErrorResponse> mapper() => NUIHttpStandardResponseEntity();
}

class NUIHttpStandardResponseEntity extends NUIEntMapper<NUIHttpStandardErrorResponse>{
  @override
  String entityName() => "NUIHttpStandardResponse";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIHttpStandardErrorResponse>(name: "timestamp", type: NUIEntType.STRING, setter: (data, value) => data.timestamp = value, getter: (data) => data.timestamp),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "status", type: NUIEntType.INTEGER, setter: (data, value) => data.status = value, getter: (data) => data.status),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "error", type: NUIEntType.STRING, setter: (data, value) => data.error = value, getter: (data) => data.error),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "message", type: NUIEntType.STRING, setter: (data, value) => data.message = value, getter: (data) => data.message),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "path", type: NUIEntType.STRING, setter: (data, value) => data.path = value, getter: (data) => data.path),
    ];
  }

  @override
  NUIHttpStandardErrorResponse newInstance() => NUIHttpStandardErrorResponse.empty();
}

==> nui_web-0.0.45.tar.gz: lib/nui_web_models.dart <==
import 'dart:convert';
import 'package:flutter/cupertino.dart';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/data/nui_ent.dart';

enum NUIWebMethod{
  PUT,
  POST,
  PATCH,
  DELETE,
  GET
}

abstract class NUIWebInterceptor{
  Future<NUIWebInterceptorResponse> intercept(String url, NUIWebMethod method, dynamic, Map<String, String> headers, dynamic body);
}

abstract class NUIOnRequestInterceptor{
  Future<NUIInterceptor> onRequestInterceptor(String url, String pathVariables, Map<String, String> prams, Map<String, String> headers, dynamic body, NUIEnt<dynamic> bodyEnt, String bodyString);
}
abstract class NUIOnResponseInterceptor{
  Future<NUIInterceptor> onResponseInterceptor(String body, NUIEntMapper entity);
}

class NUIInterceptor{

  NUIInterceptor.empty();
  NUIInterceptor({
    this.interceptedUrl,
    this.interceptedPathVariables,
    this.interceptedHeaders,
    this.interceptedParams,
    this.interceptedBody,
    this.interceptedBodyString,
    this.interceptedBodyEnt,
    this.stopIntercepting = false,
    this.noIntercepting = true
  });
  NUIInterceptor.forResponse({this.interceptedResponseBody, this.interceptedEntity, this.stopIntercepting = false, this.noIntercepting=true});
  String interceptedUrl;
  String interceptedPathVariables;
  Map<String, String> interceptedParams;
  Map<String, String> interceptedHeaders;
  dynamic interceptedBody;
  NUIEnt<dynamic> interceptedBodyEnt;
  String interceptedBodyString;
  bool stopIntercepting;
  bool noIntercepting;

  //For Response
  String interceptedResponseBody;
  NUIEntMapper interceptedEntity;
}

class NUIWebInterceptorResponse extends NUIStandardHttpResponse{
  NUIWebInterceptorResponse({String message, bool success, Map<String, dynamic> data, this.interceptResponse, int code}){
    this.message = message;
    this.success = success;
    this.data = data;
    this.code = code;
  }
  bool interceptResponse;
}

class NUIStandardHttpResponse extends NUIEnt<NUIStandardHttpResponse>{
  NUIStandardHttpResponse.empty();
  NUIStandardHttpResponse();
  String message;
  bool success;
  bool status;
  int code;
  Map<String, dynamic> data;

  @override
  NUIEntMapper<NUIStandardHttpResponse> mapper() => NUIStandardHttpResponseEntity();

  T getDataAsObj<T extends NUIEnt>(NUIEntMapper<T> entity){
    try{
      return entity.toEntity(data);
    }
    catch(e){
      logNUI("NUIStandardHttpResponse", "Failed to parse body to object with error : $e");
      return null;
    }
  }
}
class NUIStandardHttpResponseEntity extends NUIEntMapper<NUIStandardHttpResponse>{
  @override
  String entityName() => "NUIStandardHttpResponse";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIStandardHttpResponse>(name: "message", type: NUIEntType.STRING, setter: (data, value) => data.message = value, getter: (data) => data.message),
      NUIEntField<NUIStandardHttpResponse>(name: "code", type: NUIEntType.INTEGER, setter: (data, value) => data.code = value, getter: (data) => data.code),
      NUIEntField<NUIStandardHttpResponse>(name: "success", type: NUIEntType.BOOLEAN, setter: (data, value) => data.success = value, getter: (data) => data.success),
      NUIEntField<NUIStandardHttpResponse>(name: "status", type: NUIEntType.BOOLEAN, setter: (data, value) => data.status = value, getter: (data) => data.status),
      NUIEntField<NUIStandardHttpResponse>(name: "data", type: NUIEntType.MAP, setter: (data, value) => data.data = value, getter: (data) => data.data),
    ];
  }

  @override
  NUIStandardHttpResponse newInstance() => NUIStandardHttpResponse.empty();
}

class NUIHttpResponse<T>{
  NUIHttpResponse({@required this.success, @required this.code, @required this.message, this.body, this.listBody, this.response, this.responseBody, this.headers});
  bool success;
  int code;
  String message;
  T body;
  List<T> listBody;
  String response;
  Map<String, String> headers;
  dynamic responseBody;

  NUIHttpStandardErrorResponse getErrorAsEnt(){
    if(responseBody != null){
      try{
        return NUIHttpStandardResponseEntity().toEntity(responseBody);
      }catch(e){
        print("NUIHttpResponse -> Error getting error response as object with error : $e");
      }
    }
    return null;
  }
}

class NUIHttpCacheResponse extends NUIEnt<NUIHttpCacheResponse>{
  NUIHttpCacheResponse({this.response, this.headers});
  NUIHttpCacheResponse.empty();
  String response;
  Map<String, String> headers;

  T getResponseAsEnt<T extends NUIEnt>(NUIEntMapper<T> entity){
    if(isNullOrEmpty(response)) return null;
    try{
      return entity.toEntity(jsonDecode(response));
    }catch(e){
      logNUI("NUIHttpCacheResponse", "Error parsing response to entity : ${entity.entityName()}");
    }
  }

  @override
  NUIEntMapper<NUIHttpCacheResponse> mapper() => NUIHttpCacheResponseEntity();
}

class NUIHttpCacheResponseEntity extends NUIEntMapper<NUIHttpCacheResponse>{
  @override
  String entityName() => "NUIHttpCacheResponse";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIHttpCacheResponse>(name: "response", type: NUIEntType.STRING, setter: (data, value) => data.response = value, getter: (data) => data.response),
      NUIEntField<NUIHttpCacheResponse>(name: "headers", type: NUIEntType.MAP, setter: (data, value) => data.headers = value, getter: (data) => data.headers),
    ];
  }

  @override
  NUIHttpCacheResponse newInstance() => NUIHttpCacheResponse.empty();
}

class NUIHttpStandardErrorResponse extends NUIEnt<NUIHttpStandardErrorResponse>{
  NUIHttpStandardErrorResponse.empty();
  String timestamp;
  int status;
  String error;
  String message;
  String path;

  @override
  NUIEntMapper<NUIHttpStandardErrorResponse> mapper() => NUIHttpStandardResponseEntity();
}

class NUIHttpStandardResponseEntity extends NUIEntMapper<NUIHttpStandardErrorResponse>{
  @override
  String entityName() => "NUIHttpStandardResponse";

  @override
  List<NUIEntField> fields() {
    return [
      NUIEntField<NUIHttpStandardErrorResponse>(name: "timestamp", type: NUIEntType.STRING, setter: (data, value) => data.timestamp = value, getter: (data) => data.timestamp),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "status", type: NUIEntType.INTEGER, setter: (data, value) => data.status = value, getter: (data) => data.status),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "error", type: NUIEntType.STRING, setter: (data, value) => data.error = value, getter: (data) => data.error),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "message", type: NUIEntType.STRING, setter: (data, value) => data.message = value, getter: (data) => data.message),
      NUIEntField<NUIHttpStandardErrorResponse>(name: "path", type: NUIEntType.STRING, setter: (data, value) => data.path = value, getter: (data) => data.path),
    ];
  }

  @override
  NUIHttpStandardErrorResponse newInstance() => NUIHttpStandardErrorResponse.empty();
}
